from vcCommand import *
app = getApplication()
MAX_COMPONENT_SELECTION = 10

def isFrameTree(feature):
  tree = [feature]
  for f in tree:
    if f.Type == VC_FRAME:
      return True
    for kid in f.Children:
      tree.append(kid)
  return False
          
def first_state():
  sm = app.SelectionManager
  sel = sm.getSelection(VC_SELECTION_COMPONENT)
  if len(sel) == 0:
    print "No component selected."
    return
  elif len(sel) > MAX_COMPONENT_SELECTION:
    print "Please select maximum {0} components at a time.".format(MAX_COMPONENT_SELECTION)
    return

  for comp in sel:
    vcid = comp.VCID
    if not 'vcid:' in vcid:
      vcid = 'vcid:' + vcid
    origComp = app.load(vcid)
    origComp.makeUnique()
    
    dc = cc = nc = 0
    # LOOP ALL NODES FROM THE ORIGINAL COMPONENT
    orig_nodes = [origComp]
    for node in orig_nodes:
      own_kids = [x for x in node.Children if x.Component == origComp]
      orig_nodes.extend( own_kids )

    # LOOP ALL NODES FROM THE NEW COMPONENT AND REPLACE THE GEOMETRY
    nodes = [comp]
    for node in nodes:
      own_kids = [x for x in node.Children if x.Component == comp]
      nodes.extend( own_kids )
    
      # REMOVE OLD GEOMETRY
      for f in node.RootFeature.Children:
        if not isFrameTree(f): # only applicaple for hierarchy trees with no Frames
          f.delete()
          dc += 1

      # COPY NEW GEOMETRY
      for f in orig_nodes[nodes.index(node)].RootFeature.Children:
        if not isFrameTree(f): # only applicaple for hierarchy trees with no Frames
          copy = f.clone()
          node.RootFeature.attach(copy)
          cc += 1
      node.rebuild()
      nc += 1

    app.deleteComponent(origComp)
    app.render()
    sm.clear()
    sm.setSelection(comp,False)
    comp.rebuild()
    print '{0} feature trees deleted. {1} feature trees created. {2} nodes rebuilded. ({3})'.format(dc, cc, nc, comp.Name)
  
addState( first_state )